[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,64 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/stream/interfaces/hashtable_linearprobing.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
// Iterate over every item in the hashtableA, and add them to B
|
||||
|
||||
__global__ void gpu_merge_hashtable(hashtable A, const hashtable B)
|
||||
{
|
||||
unsigned int threadid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
while (threadid < reserved::kHashTableCapacity)
|
||||
{
|
||||
if (B.addr[threadid].key != reserved::kEmpty)
|
||||
{
|
||||
uint32_t value = B.addr[threadid].value;
|
||||
if (value != reserved::kEmpty)
|
||||
{
|
||||
// printf("INSERTING key %d value %d\n", pHashTableB[threadid].key, value);
|
||||
A.insert(B.addr[threadid]);
|
||||
}
|
||||
}
|
||||
threadid += blockDim.x * gridDim.x;
|
||||
}
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
stream_ctx ctx;
|
||||
|
||||
hashtable A;
|
||||
A.insert(reserved::KeyValue(107, 4));
|
||||
A.insert(reserved::KeyValue(108, 6));
|
||||
|
||||
hashtable B;
|
||||
B.insert(reserved::KeyValue(7, 14));
|
||||
B.insert(reserved::KeyValue(8, 16));
|
||||
|
||||
auto lA = ctx.logical_data(A);
|
||||
auto lB = ctx.logical_data(B);
|
||||
|
||||
ctx.task(lA.rw(), lB.read())->*[](auto stream, auto hA, auto hB) {
|
||||
gpu_merge_hashtable<<<32, 128, 0, stream>>>(hA, hB);
|
||||
cuda_safe_call(cudaGetLastError());
|
||||
};
|
||||
|
||||
ctx.host_launch(lA.read())->*[](auto hA) {
|
||||
EXPECT(hA.get(107) == 4);
|
||||
EXPECT(hA.get(108) == 6);
|
||||
EXPECT(hA.get(7) == 14);
|
||||
EXPECT(hA.get(8) == 16);
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
Reference in New Issue
Block a user